@@ -104,7 +104,7 @@ class IoT1ClickDevicesServiceClient:
     def invoke_device_method(
         self,
         DeviceId: str,
-        DeviceMethod: DeviceMethodTypeDef = None,
+        DeviceMethod: "DeviceMethodTypeDef" = None,
         DeviceMethodParameters: str = None,
     ) -> InvokeDeviceMethodResponseTypeDef:
         """
